/******************************************************************************
File: 	 setifmode.c
Purpose: Sets a Rocketport Infinity interface mode (RS232/RS422/RS485)
Project: RocketPort Infinity/Express device driver
OS: 	 FreeBSD 6
Company: Comtrol Corporation
*****************************************************************************
Copyright (C) 2008 Comtrol Corporation. All rights reserved.
RocketPort Infinity is a registered trademark of Comtrol Corporation
****************************************************************************/

#include <sys/termios.h>
#include <stdio.h>
#include <string.h>
#include <fcntl.h>
#include <stdlib.h>
#include "setifmode.h"

extern int errno;

void Usage(void);

int main(int argc, char *argv[])
{
    int fd, Mode, portnumber;
    char portname[80];

    if (argc != 3) 
	Usage();

    if ((!strcmp(argv[2], "RS232")) ||
	 (!strcmp(argv[2], "rs232")) ||
	 (!strcmp(argv[2], "Rs232"))) {

	Mode = IFMODE_RS232;
    }
	
    else if ((!strcmp(argv[2], "RS422")) ||
	     (!strcmp(argv[2], "rs422")) ||
	     (!strcmp(argv[2], "Rs422"))) {

	Mode = IFMODE_RS422;
    }
	
    else if ((!strcmp(argv[2], "RS485")) ||
	     (!strcmp(argv[2], "rs485")) ||
	     (!strcmp(argv[2], "Rs485"))) {

	Mode = IFMODE_RS485;
     }
    else {
	Usage();
    }

    portnumber = atoi(argv[1]);
    sprintf(portname, "/dev/ctrlRPI%d", portnumber);

    if ((fd = open(portname, O_RDWR|O_NONBLOCK)) != -1)  {
	if (ioctl(fd, RP2_IOCTL_SETIFMODE, &Mode) == -1)
	    fprintf(stderr, "setifmode: IOCTL Error - %s \n", strerror(errno));
	close(fd);
    }
    else {
	fprintf(stderr,"setifmode: Unable to open %s\n", argv[1]);
    }
    return 0;
}

void Usage(void )
{
    fprintf(stderr,"Usage:  setifmode portnumber ifmode  \n");
    fprintf(stderr,"\tportnumber - serial port number 0 - 131 \n");
    fprintf(stderr,"\tifmode - interface mode (RS232/RS422/RS485) \n");
    fprintf(stderr,"\tExample:  setifmode 0 RS485    sets port /dev/ttyRPI0 to RS485 mode \n");
    exit(1);
}


